# eric7.SqlBrowser.SqlBrowser

Module implementing the SQL Browser main window.

### Global Attributes

None

### Classes

SqlBrowser | Class implementing the SQL Browser main window.

### Functions

None

## SqlBrowser

Class implementing the SQL Browser main window.

### Derived from

EricMainWindow

### Class Attributes

None

### Class Methods

None

### Methods

SqlBrowser | Constructor
__about | Private slot to show the about information.
__aboutQt | Private slot to show info about Qt.
__initActions | Private method to define the user interface actions.
__initMenus | Private method to create the menus.
__initToolbars | Private method to create the toolbars.
__uiStartUp | Private slot to do some actions after the UI has started and the main loop is up.

### Static Methods

None

#### SqlBrowser (Constructor)

SqlBrowser(connections=None, parent=None)

Constructor

connections
  list of database connections to add (list of strings)
parent
  reference to the parent widget (QWidget)

#### SqlBrowser.__about

__about()

Private slot to show the about information.

#### SqlBrowser.__aboutQt

__aboutQt()

Private slot to show info about Qt.

#### SqlBrowser.__initActions

__initActions()

Private method to define the user interface actions.

#### SqlBrowser.__initMenus

__initMenus()

Private method to create the menus.

#### SqlBrowser.__initToolbars

__initToolbars()

Private method to create the toolbars.

#### SqlBrowser.__uiStartUp

__uiStartUp()

Private slot to do some actions after the UI has started and the main loop is up.

Up